@@ -120,6 +120,7 @@ struct _GeeHashMapPrivate {
 	gint _nnodes;
 	GeeHashMapNode** _nodes;
 	gint _nodes_length1;
+	gint _nodes_size;
 	gint _stamp;
 	GHashFunc _key_hash_func;
 	GEqualFunc _key_equal_func;
@@ -357,26 +358,43 @@ GeeHashMap* gee_hash_map_new (GType k_type, GBoxedCopyFunc k_dup_func, GDestroyN
 
 static GeeSet* gee_hash_map_real_get_keys (GeeMap* base) {
 	GeeHashMap * self;
-	self = GEE_HASH_MAP (base);
-	return GEE_SET (gee_hash_map_key_set_new (self->priv->k_type, ((GBoxedCopyFunc) (self->priv->k_dup_func)), self->priv->k_destroy_func, self->priv->v_type, ((GBoxedCopyFunc) (self->priv->v_dup_func)), self->priv->v_destroy_func, self));
+	self = (GeeHashMap*) base;
+	return (GeeSet*) gee_hash_map_key_set_new (self->priv->k_type, (GBoxedCopyFunc) self->priv->k_dup_func, self->priv->k_destroy_func, self->priv->v_type, (GBoxedCopyFunc) self->priv->v_dup_func, self->priv->v_destroy_func, self);
 }
 
 
 static GeeCollection* gee_hash_map_real_get_values (GeeMap* base) {
 	GeeHashMap * self;
-	self = GEE_HASH_MAP (base);
-	return GEE_COLLECTION (gee_hash_map_value_collection_new (self->priv->k_type, ((GBoxedCopyFunc) (self->priv->k_dup_func)), self->priv->k_destroy_func, self->priv->v_type, ((GBoxedCopyFunc) (self->priv->v_dup_func)), self->priv->v_destroy_func, self));
+	self = (GeeHashMap*) base;
+	return (GeeCollection*) gee_hash_map_value_collection_new (self->priv->k_type, (GBoxedCopyFunc) self->priv->k_dup_func, self->priv->k_destroy_func, self->priv->v_type, (GBoxedCopyFunc) self->priv->v_dup_func, self->priv->v_destroy_func, self);
 }
 
 
 static GeeHashMapNode** gee_hash_map_lookup_node (GeeHashMap* self, gconstpointer key) {
 	guint hash_value;
 	GeeHashMapNode** node;
-	g_return_val_if_fail (GEE_IS_HASH_MAP (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	hash_value = self->priv->_key_hash_func (key);
 	node = &self->priv->_nodes[hash_value % self->priv->_array_size];
-	while (((*node)) != NULL && (hash_value != ((*node))->key_hash || !self->priv->_key_equal_func (((*node))->key, key))) {
-		node = &(((*node))->next);
+	while (TRUE) {
+		gboolean _tmp0;
+		_tmp0 = FALSE;
+		if ((*node) != NULL) {
+			gboolean _tmp1;
+			_tmp1 = FALSE;
+			if (hash_value != (*node)->key_hash) {
+				_tmp1 = TRUE;
+			} else {
+				_tmp1 = !self->priv->_key_equal_func ((*node)->key, key);
+			}
+			_tmp0 = (_tmp1);
+		} else {
+			_tmp0 = FALSE;
+		}
+		if (!_tmp0) {
+			break;
+		}
+		node = &((*node)->next);
 	}
 	return node;
 }
@@ -385,7 +403,7 @@ static GeeHashMapNode** gee_hash_map_lookup_node (GeeHashMap* self, gconstpointe
 static gboolean gee_hash_map_real_contains (GeeMap* base, gconstpointer key) {
 	GeeHashMap * self;
 	GeeHashMapNode** node;
-	self = GEE_HASH_MAP (base);
+	self = (GeeHashMap*) base;
 	node = gee_hash_map_lookup_node (self, key);
 	return ((*node) != NULL);
 }
@@ -394,12 +412,12 @@ static gboolean gee_hash_map_real_contains (GeeMap* base, gconstpointer key) {
 static gpointer gee_hash_map_real_get (GeeMap* base, gconstpointer key) {
 	GeeHashMap * self;
 	GeeHashMapNode* node;
-	self = GEE_HASH_MAP (base);
-	node = ((*gee_hash_map_lookup_node (self, key)));
+	self = (GeeHashMap*) base;
+	node = (*gee_hash_map_lookup_node (self, key));
 	if (node != NULL) {
 		gconstpointer _tmp0;
 		_tmp0 = NULL;
-		return (_tmp0 = node->value, (_tmp0 == NULL || self->priv->v_dup_func == NULL ? ((gpointer) (_tmp0)) : self->priv->v_dup_func (((gpointer) (_tmp0)))));
+		return (_tmp0 = node->value, ((_tmp0 == NULL) || (self->priv->v_dup_func == NULL)) ? ((gpointer) _tmp0) : self->priv->v_dup_func ((gpointer) _tmp0));
 	} else {
 		return NULL;
 	}
@@ -409,14 +427,14 @@ static gpointer gee_hash_map_real_get (GeeMap* base, gconstpointer key) {
 static void gee_hash_map_real_set (GeeMap* base, gconstpointer key, gconstpointer value) {
 	GeeHashMap * self;
 	GeeHashMapNode** node;
-	self = GEE_HASH_MAP (base);
+	self = (GeeHashMap*) base;
 	node = gee_hash_map_lookup_node (self, key);
 	if ((*node) != NULL) {
 		gpointer _tmp1;
 		gconstpointer _tmp0;
 		_tmp1 = NULL;
 		_tmp0 = NULL;
-		((*node))->value = (_tmp1 = (_tmp0 = value, (_tmp0 == NULL || self->priv->v_dup_func == NULL ? ((gpointer) (_tmp0)) : self->priv->v_dup_func (((gpointer) (_tmp0))))), (((*node))->value == NULL || self->priv->v_destroy_func == NULL ? NULL : (((*node))->value = (self->priv->v_destroy_func (((*node))->value), NULL))), _tmp1);
+		(*node)->value = (_tmp1 = (_tmp0 = value, ((_tmp0 == NULL) || (self->priv->v_dup_func == NULL)) ? ((gpointer) _tmp0) : self->priv->v_dup_func ((gpointer) _tmp0)), (((*node)->value == NULL) || (self->priv->v_destroy_func == NULL)) ? NULL : ((*node)->value = (self->priv->v_destroy_func ((*node)->value), NULL)), _tmp1);
 	} else {
 		guint hash_value;
 		gconstpointer _tmp3;
@@ -424,7 +442,7 @@ static void gee_hash_map_real_set (GeeMap* base, gconstpointer key, gconstpointe
 		hash_value = self->priv->_key_hash_func (key);
 		_tmp3 = NULL;
 		_tmp2 = NULL;
-		(*node) = gee_hash_map_node_new ((_tmp2 = key, (_tmp2 == NULL || self->priv->k_dup_func == NULL ? ((gpointer) (_tmp2)) : self->priv->k_dup_func (((gpointer) (_tmp2))))), (_tmp3 = value, (_tmp3 == NULL || self->priv->v_dup_func == NULL ? ((gpointer) (_tmp3)) : self->priv->v_dup_func (((gpointer) (_tmp3))))), hash_value);
+		*node = gee_hash_map_node_new ((_tmp2 = key, ((_tmp2 == NULL) || (self->priv->k_dup_func == NULL)) ? ((gpointer) _tmp2) : self->priv->k_dup_func ((gpointer) _tmp2)), (_tmp3 = value, ((_tmp3 == NULL) || (self->priv->v_dup_func == NULL)) ? ((gpointer) _tmp3) : self->priv->v_dup_func ((gpointer) _tmp3)), hash_value);
 		self->priv->_nnodes++;
 		gee_hash_map_resize (self);
 	}
@@ -435,16 +453,16 @@ static void gee_hash_map_real_set (GeeMap* base, gconstpointer key, gconstpointe
 static gboolean gee_hash_map_real_remove (GeeMap* base, gconstpointer key) {
 	GeeHashMap * self;
 	GeeHashMapNode** node;
-	self = GEE_HASH_MAP (base);
+	self = (GeeHashMap*) base;
 	node = gee_hash_map_lookup_node (self, key);
 	if ((*node) != NULL) {
 		gpointer _tmp0;
 		gpointer _tmp1;
 		_tmp0 = NULL;
-		((*node))->key = (_tmp0 = NULL, (((*node))->key == NULL || self->priv->k_destroy_func == NULL ? NULL : (((*node))->key = (self->priv->k_destroy_func (((*node))->key), NULL))), _tmp0);
+		(*node)->key = (_tmp0 = NULL, (((*node)->key == NULL) || (self->priv->k_destroy_func == NULL)) ? NULL : ((*node)->key = (self->priv->k_destroy_func ((*node)->key), NULL)), _tmp0);
 		_tmp1 = NULL;
-		((*node))->value = (_tmp1 = NULL, (((*node))->value == NULL || self->priv->v_destroy_func == NULL ? NULL : (((*node))->value = (self->priv->v_destroy_func (((*node))->value), NULL))), _tmp1);
-		(*node) = ((*node))->next;
+		(*node)->value = (_tmp1 = NULL, (((*node)->value == NULL) || (self->priv->v_destroy_func == NULL)) ? NULL : ((*node)->value = (self->priv->v_destroy_func ((*node)->value), NULL)), _tmp1);
+		*node = (*node)->next;
 		self->priv->_nnodes--;
 		gee_hash_map_resize (self);
 		self->priv->_stamp++;
@@ -456,7 +474,7 @@ static gboolean gee_hash_map_real_remove (GeeMap* base, gconstpointer key) {
 
 static void gee_hash_map_real_clear (GeeMap* base) {
 	GeeHashMap * self;
-	self = GEE_HASH_MAP (base);
+	self = (GeeHashMap*) base;
 	{
 		gint i;
 		i = 0;
@@ -475,15 +493,15 @@ static void gee_hash_map_real_clear (GeeMap* base) {
 				_tmp1 = NULL;
 				next = (_tmp1 = node->next, node->next = NULL, _tmp1);
 				_tmp2 = NULL;
-				node->key = (_tmp2 = NULL, (node->key == NULL || self->priv->k_destroy_func == NULL ? NULL : (node->key = (self->priv->k_destroy_func (node->key), NULL))), _tmp2);
+				node->key = (_tmp2 = NULL, ((node->key == NULL) || (self->priv->k_destroy_func == NULL)) ? NULL : (node->key = (self->priv->k_destroy_func (node->key), NULL)), _tmp2);
 				_tmp3 = NULL;
-				node->value = (_tmp3 = NULL, (node->value == NULL || self->priv->v_destroy_func == NULL ? NULL : (node->value = (self->priv->v_destroy_func (node->value), NULL))), _tmp3);
+				node->value = (_tmp3 = NULL, ((node->value == NULL) || (self->priv->v_destroy_func == NULL)) ? NULL : (node->value = (self->priv->v_destroy_func (node->value), NULL)), _tmp3);
 				_tmp5 = NULL;
 				_tmp4 = NULL;
-				node = (_tmp5 = (_tmp4 = next, next = NULL, _tmp4), (node == NULL ? NULL : (node = (gee_hash_map_node_free (node), NULL))), _tmp5);
-				(next == NULL ? NULL : (next = (gee_hash_map_node_free (next), NULL)));
+				node = (_tmp5 = (_tmp4 = next, next = NULL, _tmp4), (node == NULL) ? NULL : (node = (gee_hash_map_node_free (node), NULL)), _tmp5);
+				(next == NULL) ? NULL : (next = (gee_hash_map_node_free (next), NULL));
 			}
-			(node == NULL ? NULL : (node = (gee_hash_map_node_free (node), NULL)));
+			(node == NULL) ? NULL : (node = (gee_hash_map_node_free (node), NULL));
 		}
 	}
 	self->priv->_nnodes = 0;
@@ -492,91 +510,113 @@ static void gee_hash_map_real_clear (GeeMap* base) {
 
 
 static void gee_hash_map_resize (GeeHashMap* self) {
-	g_return_if_fail (GEE_IS_HASH_MAP (self));
-	if ((self->priv->_array_size >= 3 * self->priv->_nnodes && self->priv->_array_size >= GEE_HASH_MAP_MIN_SIZE) || (3 * self->priv->_array_size <= self->priv->_nnodes && self->priv->_array_size < GEE_HASH_MAP_MAX_SIZE)) {
+	gboolean _tmp0;
+	gboolean _tmp1;
+	g_return_if_fail (self != NULL);
+	_tmp0 = FALSE;
+	_tmp1 = FALSE;
+	if (self->priv->_array_size >= (3 * self->priv->_nnodes)) {
+		_tmp1 = self->priv->_array_size >= GEE_HASH_MAP_MIN_SIZE;
+	} else {
+		_tmp1 = FALSE;
+	}
+	if ((_tmp1)) {
+		_tmp0 = TRUE;
+	} else {
+		gboolean _tmp2;
+		_tmp2 = FALSE;
+		if ((3 * self->priv->_array_size) <= self->priv->_nnodes) {
+			_tmp2 = self->priv->_array_size < GEE_HASH_MAP_MAX_SIZE;
+		} else {
+			_tmp2 = FALSE;
+		}
+		_tmp0 = (_tmp2);
+	}
+	if (_tmp0) {
 		gint new_array_size;
-		GeeHashMapNode** _tmp0;
+		GeeHashMapNode** _tmp3;
+		gint new_nodes_size;
 		gint new_nodes_length1;
 		GeeHashMapNode** new_nodes;
-		GeeHashMapNode** _tmp12;
-		GeeHashMapNode** _tmp11;
-		new_array_size = ((gint) (g_spaced_primes_closest (((guint) (self->priv->_nnodes)))));
+		GeeHashMapNode** _tmp15;
+		GeeHashMapNode** _tmp14;
+		new_array_size = (gint) g_spaced_primes_closest ((guint) self->priv->_nnodes);
 		new_array_size = CLAMP (new_array_size, GEE_HASH_MAP_MIN_SIZE, GEE_HASH_MAP_MAX_SIZE);
-		_tmp0 = NULL;
-		new_nodes = (_tmp0 = g_new0 (GeeHashMapNode*, new_array_size + 1), new_nodes_length1 = new_array_size, _tmp0);
+		_tmp3 = NULL;
+		new_nodes = (_tmp3 = g_new0 (GeeHashMapNode*, new_array_size + 1), new_nodes_length1 = new_array_size, new_nodes_size = new_nodes_length1, _tmp3);
 		{
 			gint i;
 			i = 0;
 			for (; i < self->priv->_array_size; i++) {
 				GeeHashMapNode* node;
 				GeeHashMapNode* next;
+				GeeHashMapNode* _tmp7;
+				GeeHashMapNode* _tmp6;
+				GeeHashMapNode* _tmp5;
 				GeeHashMapNode* _tmp4;
-				GeeHashMapNode* _tmp3;
-				GeeHashMapNode* _tmp2;
-				GeeHashMapNode* _tmp1;
 				node = NULL;
 				next = NULL;
+				_tmp7 = NULL;
+				_tmp6 = NULL;
+				_tmp5 = NULL;
 				_tmp4 = NULL;
-				_tmp3 = NULL;
-				_tmp2 = NULL;
-				_tmp1 = NULL;
-				for (node = (_tmp2 = (_tmp1 = self->priv->_nodes[i], self->priv->_nodes[i] = NULL, _tmp1), (node == NULL ? NULL : (node = (gee_hash_map_node_free (node), NULL))), _tmp2); node != NULL; node = (_tmp4 = (_tmp3 = next, next = NULL, _tmp3), (node == NULL ? NULL : (node = (gee_hash_map_node_free (node), NULL))), _tmp4)) {
-					GeeHashMapNode* _tmp6;
-					GeeHashMapNode* _tmp5;
-					guint hash_val;
-					GeeHashMapNode* _tmp8;
-					GeeHashMapNode* _tmp7;
-					GeeHashMapNode* _tmp10;
+				for (node = (_tmp5 = (_tmp4 = self->priv->_nodes[i], self->priv->_nodes[i] = NULL, _tmp4), (node == NULL) ? NULL : (node = (gee_hash_map_node_free (node), NULL)), _tmp5); node != NULL; node = (_tmp7 = (_tmp6 = next, next = NULL, _tmp6), (node == NULL) ? NULL : (node = (gee_hash_map_node_free (node), NULL)), _tmp7)) {
 					GeeHashMapNode* _tmp9;
-					_tmp6 = NULL;
-					_tmp5 = NULL;
-					next = (_tmp6 = (_tmp5 = node->next, node->next = NULL, _tmp5), (next == NULL ? NULL : (next = (gee_hash_map_node_free (next), NULL))), _tmp6);
-					hash_val = node->key_hash % new_array_size;
-					_tmp8 = NULL;
-					_tmp7 = NULL;
-					node->next = (_tmp8 = (_tmp7 = new_nodes[hash_val], new_nodes[hash_val] = NULL, _tmp7), (node->next == NULL ? NULL : (node->next = (gee_hash_map_node_free (node->next), NULL))), _tmp8);
-					_tmp10 = NULL;
+					GeeHashMapNode* _tmp8;
+					guint hash_val;
+					GeeHashMapNode* _tmp11;
+					GeeHashMapNode* _tmp10;
+					GeeHashMapNode* _tmp13;
+					GeeHashMapNode* _tmp12;
 					_tmp9 = NULL;
-					new_nodes[hash_val] = (_tmp10 = (_tmp9 = node, node = NULL, _tmp9), (new_nodes[hash_val] == NULL ? NULL : (new_nodes[hash_val] = (gee_hash_map_node_free (new_nodes[hash_val]), NULL))), _tmp10);
+					_tmp8 = NULL;
+					next = (_tmp9 = (_tmp8 = node->next, node->next = NULL, _tmp8), (next == NULL) ? NULL : (next = (gee_hash_map_node_free (next), NULL)), _tmp9);
+					hash_val = node->key_hash % new_array_size;
+					_tmp11 = NULL;
+					_tmp10 = NULL;
+					node->next = (_tmp11 = (_tmp10 = new_nodes[hash_val], new_nodes[hash_val] = NULL, _tmp10), (node->next == NULL) ? NULL : (node->next = (gee_hash_map_node_free (node->next), NULL)), _tmp11);
+					_tmp13 = NULL;
+					_tmp12 = NULL;
+					new_nodes[hash_val] = (_tmp13 = (_tmp12 = node, node = NULL, _tmp12), (new_nodes[hash_val] == NULL) ? NULL : (new_nodes[hash_val] = (gee_hash_map_node_free (new_nodes[hash_val]), NULL)), _tmp13);
 				}
-				(node == NULL ? NULL : (node = (gee_hash_map_node_free (node), NULL)));
-				(next == NULL ? NULL : (next = (gee_hash_map_node_free (next), NULL)));
+				(node == NULL) ? NULL : (node = (gee_hash_map_node_free (node), NULL));
+				(next == NULL) ? NULL : (next = (gee_hash_map_node_free (next), NULL));
 			}
 		}
-		_tmp12 = NULL;
-		_tmp11 = NULL;
-		self->priv->_nodes = (_tmp12 = (_tmp11 = new_nodes, new_nodes = NULL, _tmp11), (self->priv->_nodes = (_vala_array_free (self->priv->_nodes, self->priv->_nodes_length1, ((GDestroyNotify) (gee_hash_map_node_free))), NULL)), self->priv->_nodes_length1 = new_nodes_length1, _tmp12);
+		_tmp15 = NULL;
+		_tmp14 = NULL;
+		self->priv->_nodes = (_tmp15 = (_tmp14 = new_nodes, new_nodes = NULL, _tmp14), self->priv->_nodes = (_vala_array_free (self->priv->_nodes, self->priv->_nodes_length1, (GDestroyNotify) gee_hash_map_node_free), NULL), self->priv->_nodes_length1 = new_nodes_length1, self->priv->_nodes_size = self->priv->_nodes_length1, _tmp15);
 		self->priv->_array_size = new_array_size;
-		new_nodes = (_vala_array_free (new_nodes, new_nodes_length1, ((GDestroyNotify) (gee_hash_map_node_free))), NULL);
+		new_nodes = (_vala_array_free (new_nodes, new_nodes_length1, (GDestroyNotify) gee_hash_map_node_free), NULL);
 	}
 }
 
 
 static gint gee_hash_map_real_get_size (GeeMap* base) {
 	GeeHashMap* self;
-	self = GEE_HASH_MAP (base);
+	self = (GeeHashMap*) base;
 	return self->priv->_nnodes;
 }
 
 
 void gee_hash_map_set_key_hash_func (GeeHashMap* self, GHashFunc value) {
-	g_return_if_fail (GEE_IS_HASH_MAP (self));
+	g_return_if_fail (self != NULL);
 	self->priv->_key_hash_func = value;
-	g_object_notify (((GObject *) (self)), "key-hash-func");
+	g_object_notify ((GObject *) self, "key-hash-func");
 }
 
 
 void gee_hash_map_set_key_equal_func (GeeHashMap* self, GEqualFunc value) {
-	g_return_if_fail (GEE_IS_HASH_MAP (self));
+	g_return_if_fail (self != NULL);
 	self->priv->_key_equal_func = value;
-	g_object_notify (((GObject *) (self)), "key-equal-func");
+	g_object_notify ((GObject *) self, "key-equal-func");
 }
 
 
 void gee_hash_map_set_value_equal_func (GeeHashMap* self, GEqualFunc value) {
-	g_return_if_fail (GEE_IS_HASH_MAP (self));
+	g_return_if_fail (self != NULL);
 	self->priv->_value_equal_func = value;
-	g_object_notify (((GObject *) (self)), "value-equal-func");
+	g_object_notify ((GObject *) self, "value-equal-func");
 }
 
 
@@ -593,7 +633,7 @@ static GObject * gee_hash_map_constructor (GType type, guint n_construct_propert
 		GeeHashMapNode** _tmp0;
 		self->priv->_array_size = GEE_HASH_MAP_MIN_SIZE;
 		_tmp0 = NULL;
-		self->priv->_nodes = (_tmp0 = g_new0 (GeeHashMapNode*, self->priv->_array_size + 1), (self->priv->_nodes = (_vala_array_free (self->priv->_nodes, self->priv->_nodes_length1, ((GDestroyNotify) (gee_hash_map_node_free))), NULL)), self->priv->_nodes_length1 = self->priv->_array_size, _tmp0);
+		self->priv->_nodes = (_tmp0 = g_new0 (GeeHashMapNode*, self->priv->_array_size + 1), self->priv->_nodes = (_vala_array_free (self->priv->_nodes, self->priv->_nodes_length1, (GDestroyNotify) gee_hash_map_node_free), NULL), self->priv->_nodes_length1 = self->priv->_array_size, self->priv->_nodes_size = self->priv->_nodes_length1, _tmp0);
 	}
 	return obj;
 }
@@ -619,7 +659,7 @@ static void gee_hash_map_node_instance_init (GeeHashMapNode * self) {
 
 
 static void gee_hash_map_node_free (GeeHashMapNode* self) {
-	(self->next == NULL ? NULL : (self->next = (gee_hash_map_node_free (self->next), NULL)));
+	(self->next == NULL) ? NULL : (self->next = (gee_hash_map_node_free (self->next), NULL));
 	g_slice_free (GeeHashMapNode, self);
 }
 
@@ -628,7 +668,7 @@ static GeeHashMapKeySet* gee_hash_map_key_set_construct (GType object_type, GTyp
 	GParameter * __params;
 	GParameter * __params_it;
 	GeeHashMapKeySet * self;
-	g_return_val_if_fail (GEE_IS_HASH_MAP (map), NULL);
+	g_return_val_if_fail (map != NULL, NULL);
 	__params = g_new0 (GParameter, 6);
 	__params_it = __params;
 	__params_it->name = "k-type";
@@ -673,70 +713,71 @@ static GeeHashMapKeySet* gee_hash_map_key_set_new (GType k_type, GBoxedCopyFunc
 
 static GType gee_hash_map_key_set_real_get_element_type (GeeIterable* base) {
 	GeeHashMapKeySet * self;
-	self = GEE_HASH_MAP_KEY_SET (base);
+	self = (GeeHashMapKeySet*) base;
 	return self->priv->k_type;
 }
 
 
 static GeeIterator* gee_hash_map_key_set_real_iterator (GeeIterable* base) {
 	GeeHashMapKeySet * self;
-	self = GEE_HASH_MAP_KEY_SET (base);
-	return GEE_ITERATOR (gee_hash_map_key_iterator_new (self->priv->k_type, ((GBoxedCopyFunc) (self->priv->k_dup_func)), self->priv->k_destroy_func, self->priv->v_type, ((GBoxedCopyFunc) (self->priv->v_dup_func)), self->priv->v_destroy_func, self->priv->_map));
+	self = (GeeHashMapKeySet*) base;
+	return (GeeIterator*) gee_hash_map_key_iterator_new (self->priv->k_type, (GBoxedCopyFunc) self->priv->k_dup_func, self->priv->k_destroy_func, self->priv->v_type, (GBoxedCopyFunc) self->priv->v_dup_func, self->priv->v_destroy_func, self->priv->_map);
 }
 
 
 static gboolean gee_hash_map_key_set_real_add (GeeCollection* base, gconstpointer key) {
 	GeeHashMapKeySet * self;
-	self = GEE_HASH_MAP_KEY_SET (base);
+	self = (GeeHashMapKeySet*) base;
 	g_assert_not_reached ();
 }
 
 
 static void gee_hash_map_key_set_real_clear (GeeCollection* base) {
 	GeeHashMapKeySet * self;
-	self = GEE_HASH_MAP_KEY_SET (base);
+	self = (GeeHashMapKeySet*) base;
 	g_assert_not_reached ();
 }
 
 
 static gboolean gee_hash_map_key_set_real_remove (GeeCollection* base, gconstpointer key) {
 	GeeHashMapKeySet * self;
-	self = GEE_HASH_MAP_KEY_SET (base);
+	self = (GeeHashMapKeySet*) base;
 	g_assert_not_reached ();
 }
 
 
 static gboolean gee_hash_map_key_set_real_contains (GeeCollection* base, gconstpointer key) {
 	GeeHashMapKeySet * self;
-	self = GEE_HASH_MAP_KEY_SET (base);
-	return gee_map_contains (GEE_MAP (self->priv->_map), key);
+	self = (GeeHashMapKeySet*) base;
+	return gee_map_contains ((GeeMap*) self->priv->_map, key);
 }
 
 
 static void gee_hash_map_key_set_set_map (GeeHashMapKeySet* self, GeeHashMap* value) {
 	GeeHashMap* _tmp1;
 	GeeHashMap* _tmp0;
-	g_return_if_fail (GEE_HASH_MAP_IS_KEY_SET (self));
+	g_return_if_fail (self != NULL);
 	_tmp1 = NULL;
 	_tmp0 = NULL;
-	self->priv->_map = (_tmp1 = (_tmp0 = value, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0))), (self->priv->_map == NULL ? NULL : (self->priv->_map = (g_object_unref (self->priv->_map), NULL))), _tmp1);
-	g_object_notify (((GObject *) (self)), "map");
+	self->priv->_map = (_tmp1 = (_tmp0 = value, (_tmp0 == NULL) ? NULL : g_object_ref (_tmp0)), (self->priv->_map == NULL) ? NULL : (self->priv->_map = (g_object_unref (self->priv->_map), NULL)), _tmp1);
+	g_object_notify ((GObject *) self, "map");
 }
 
 
 static gint gee_hash_map_key_set_real_get_size (GeeCollection* base) {
 	GeeHashMapKeySet* self;
-	self = GEE_HASH_MAP_KEY_SET (base);
-	return gee_map_get_size (GEE_MAP (self->priv->_map));
+	self = (GeeHashMapKeySet*) base;
+	return gee_map_get_size ((GeeMap*) self->priv->_map);
 }
 
 
 static void gee_hash_map_key_set_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	GeeHashMapKeySet * self;
+	gpointer boxed;
 	self = GEE_HASH_MAP_KEY_SET (object);
 	switch (property_id) {
 		case GEE_HASH_MAP_KEY_SET_SIZE:
-		g_value_set_int (value, gee_collection_get_size (GEE_COLLECTION (self)));
+		g_value_set_int (value, gee_collection_get_size ((GeeCollection*) self));
 		break;
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -752,6 +793,9 @@ static void gee_hash_map_key_set_set_property (GObject * object, guint property_
 		case GEE_HASH_MAP_KEY_SET_MAP:
 		gee_hash_map_key_set_set_map (self, g_value_get_object (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 		case GEE_HASH_MAP_KEY_SET_K_TYPE:
 		self->priv->k_type = g_value_get_gtype (value);
 		break;
@@ -770,9 +814,6 @@ static void gee_hash_map_key_set_set_property (GObject * object, guint property_
 		case GEE_HASH_MAP_KEY_SET_V_DESTROY_FUNC:
 		self->priv->v_destroy_func = g_value_get_pointer (value);
 		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
 	}
 }
 
@@ -824,7 +865,7 @@ static void gee_hash_map_key_set_instance_init (GeeHashMapKeySet * self) {
 static void gee_hash_map_key_set_finalize (GObject* obj) {
 	GeeHashMapKeySet * self;
 	self = GEE_HASH_MAP_KEY_SET (obj);
-	(self->priv->_map == NULL ? NULL : (self->priv->_map = (g_object_unref (self->priv->_map), NULL)));
+	(self->priv->_map == NULL) ? NULL : (self->priv->_map = (g_object_unref (self->priv->_map), NULL));
 	G_OBJECT_CLASS (gee_hash_map_key_set_parent_class)->finalize (obj);
 }
 
@@ -849,7 +890,7 @@ static GeeHashMapKeyIterator* gee_hash_map_key_iterator_construct (GType object_
 	GParameter * __params;
 	GParameter * __params_it;
 	GeeHashMapKeyIterator * self;
-	g_return_val_if_fail (GEE_IS_HASH_MAP (map), NULL);
+	g_return_val_if_fail (map != NULL, NULL);
 	__params = g_new0 (GParameter, 6);
 	__params_it = __params;
 	__params_it->name = "k-type";
@@ -894,11 +935,21 @@ static GeeHashMapKeyIterator* gee_hash_map_key_iterator_new (GType k_type, GBoxe
 
 static gboolean gee_hash_map_key_iterator_real_next (GeeIterator* base) {
 	GeeHashMapKeyIterator * self;
-	self = GEE_HASH_MAP_KEY_ITERATOR (base);
+	self = (GeeHashMapKeyIterator*) base;
 	if (self->priv->_node != NULL) {
 		self->priv->_node = self->priv->_node->next;
 	}
-	while (self->priv->_node == NULL && self->priv->_index + 1 < self->priv->_map->priv->_array_size) {
+	while (TRUE) {
+		gboolean _tmp0;
+		_tmp0 = FALSE;
+		if (self->priv->_node == NULL) {
+			_tmp0 = (self->priv->_index + 1) < self->priv->_map->priv->_array_size;
+		} else {
+			_tmp0 = FALSE;
+		}
+		if (!_tmp0) {
+			break;
+		}
 		self->priv->_index++;
 		self->priv->_node = self->priv->_map->priv->_nodes[self->priv->_index];
 	}
@@ -909,28 +960,29 @@ static gboolean gee_hash_map_key_iterator_real_next (GeeIterator* base) {
 static gpointer gee_hash_map_key_iterator_real_get (GeeIterator* base) {
 	GeeHashMapKeyIterator * self;
 	gconstpointer _tmp0;
-	self = GEE_HASH_MAP_KEY_ITERATOR (base);
+	self = (GeeHashMapKeyIterator*) base;
 	g_assert (self->priv->_stamp == self->priv->_map->priv->_stamp);
 	g_assert (self->priv->_node != NULL);
 	_tmp0 = NULL;
-	return (_tmp0 = self->priv->_node->key, (_tmp0 == NULL || self->priv->k_dup_func == NULL ? ((gpointer) (_tmp0)) : self->priv->k_dup_func (((gpointer) (_tmp0)))));
+	return (_tmp0 = self->priv->_node->key, ((_tmp0 == NULL) || (self->priv->k_dup_func == NULL)) ? ((gpointer) _tmp0) : self->priv->k_dup_func ((gpointer) _tmp0));
 }
 
 
 static void gee_hash_map_key_iterator_set_map (GeeHashMapKeyIterator* self, GeeHashMap* value) {
 	GeeHashMap* _tmp1;
 	GeeHashMap* _tmp0;
-	g_return_if_fail (GEE_HASH_MAP_IS_KEY_ITERATOR (self));
+	g_return_if_fail (self != NULL);
 	_tmp1 = NULL;
 	_tmp0 = NULL;
-	self->priv->_map = (_tmp1 = (_tmp0 = value, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0))), (self->priv->_map == NULL ? NULL : (self->priv->_map = (g_object_unref (self->priv->_map), NULL))), _tmp1);
+	self->priv->_map = (_tmp1 = (_tmp0 = value, (_tmp0 == NULL) ? NULL : g_object_ref (_tmp0)), (self->priv->_map == NULL) ? NULL : (self->priv->_map = (g_object_unref (self->priv->_map), NULL)), _tmp1);
 	self->priv->_stamp = self->priv->_map->priv->_stamp;
-	g_object_notify (((GObject *) (self)), "map");
+	g_object_notify ((GObject *) self, "map");
 }
 
 
 static void gee_hash_map_key_iterator_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	GeeHashMapKeyIterator * self;
+	gpointer boxed;
 	self = GEE_HASH_MAP_KEY_ITERATOR (object);
 	switch (property_id) {
 		default:
@@ -947,6 +999,9 @@ static void gee_hash_map_key_iterator_set_property (GObject * object, guint prop
 		case GEE_HASH_MAP_KEY_ITERATOR_MAP:
 		gee_hash_map_key_iterator_set_map (self, g_value_get_object (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 		case GEE_HASH_MAP_KEY_ITERATOR_K_TYPE:
 		self->priv->k_type = g_value_get_gtype (value);
 		break;
@@ -965,9 +1020,6 @@ static void gee_hash_map_key_iterator_set_property (GObject * object, guint prop
 		case GEE_HASH_MAP_KEY_ITERATOR_V_DESTROY_FUNC:
 		self->priv->v_destroy_func = g_value_get_pointer (value);
 		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
 	}
 }
 
@@ -1004,7 +1056,7 @@ static void gee_hash_map_key_iterator_instance_init (GeeHashMapKeyIterator * sel
 static void gee_hash_map_key_iterator_finalize (GObject* obj) {
 	GeeHashMapKeyIterator * self;
 	self = GEE_HASH_MAP_KEY_ITERATOR (obj);
-	(self->priv->_map == NULL ? NULL : (self->priv->_map = (g_object_unref (self->priv->_map), NULL)));
+	(self->priv->_map == NULL) ? NULL : (self->priv->_map = (g_object_unref (self->priv->_map), NULL));
 	G_OBJECT_CLASS (gee_hash_map_key_iterator_parent_class)->finalize (obj);
 }
 
@@ -1025,7 +1077,7 @@ static GeeHashMapValueCollection* gee_hash_map_value_collection_construct (GType
 	GParameter * __params;
 	GParameter * __params_it;
 	GeeHashMapValueCollection * self;
-	g_return_val_if_fail (GEE_IS_HASH_MAP (map), NULL);
+	g_return_val_if_fail (map != NULL, NULL);
 	__params = g_new0 (GParameter, 6);
 	__params_it = __params;
 	__params_it->name = "k-type";
@@ -1070,35 +1122,35 @@ static GeeHashMapValueCollection* gee_hash_map_value_collection_new (GType k_typ
 
 static GType gee_hash_map_value_collection_real_get_element_type (GeeIterable* base) {
 	GeeHashMapValueCollection * self;
-	self = GEE_HASH_MAP_VALUE_COLLECTION (base);
+	self = (GeeHashMapValueCollection*) base;
 	return self->priv->v_type;
 }
 
 
 static GeeIterator* gee_hash_map_value_collection_real_iterator (GeeIterable* base) {
 	GeeHashMapValueCollection * self;
-	self = GEE_HASH_MAP_VALUE_COLLECTION (base);
-	return GEE_ITERATOR (gee_hash_map_value_iterator_new (self->priv->k_type, ((GBoxedCopyFunc) (self->priv->k_dup_func)), self->priv->k_destroy_func, self->priv->v_type, ((GBoxedCopyFunc) (self->priv->v_dup_func)), self->priv->v_destroy_func, self->priv->_map));
+	self = (GeeHashMapValueCollection*) base;
+	return (GeeIterator*) gee_hash_map_value_iterator_new (self->priv->k_type, (GBoxedCopyFunc) self->priv->k_dup_func, self->priv->k_destroy_func, self->priv->v_type, (GBoxedCopyFunc) self->priv->v_dup_func, self->priv->v_destroy_func, self->priv->_map);
 }
 
 
 static gboolean gee_hash_map_value_collection_real_add (GeeCollection* base, gconstpointer value) {
 	GeeHashMapValueCollection * self;
-	self = GEE_HASH_MAP_VALUE_COLLECTION (base);
+	self = (GeeHashMapValueCollection*) base;
 	g_assert_not_reached ();
 }
 
 
 static void gee_hash_map_value_collection_real_clear (GeeCollection* base) {
 	GeeHashMapValueCollection * self;
-	self = GEE_HASH_MAP_VALUE_COLLECTION (base);
+	self = (GeeHashMapValueCollection*) base;
 	g_assert_not_reached ();
 }
 
 
 static gboolean gee_hash_map_value_collection_real_remove (GeeCollection* base, gconstpointer value) {
 	GeeHashMapValueCollection * self;
-	self = GEE_HASH_MAP_VALUE_COLLECTION (base);
+	self = (GeeHashMapValueCollection*) base;
 	g_assert_not_reached ();
 }
 
@@ -1107,45 +1159,46 @@ static gboolean gee_hash_map_value_collection_real_contains (GeeCollection* base
 	GeeHashMapValueCollection * self;
 	GeeIterator* it;
 	gboolean _tmp3;
-	self = GEE_HASH_MAP_VALUE_COLLECTION (base);
-	it = gee_iterable_iterator (GEE_ITERABLE (self));
+	self = (GeeHashMapValueCollection*) base;
+	it = gee_iterable_iterator ((GeeIterable*) self);
 	while (gee_iterator_next (it)) {
 		gpointer _tmp0;
 		gboolean _tmp1;
 		_tmp0 = NULL;
-		if ((_tmp1 = self->priv->_map->priv->_value_equal_func ((_tmp0 = gee_iterator_get (it)), value), (_tmp0 == NULL || self->priv->v_destroy_func == NULL ? NULL : (_tmp0 = (self->priv->v_destroy_func (_tmp0), NULL))), _tmp1)) {
+		if ((_tmp1 = self->priv->_map->priv->_value_equal_func (_tmp0 = gee_iterator_get (it), value), ((_tmp0 == NULL) || (self->priv->v_destroy_func == NULL)) ? NULL : (_tmp0 = (self->priv->v_destroy_func (_tmp0), NULL)), _tmp1)) {
 			gboolean _tmp2;
-			return (_tmp2 = TRUE, (it == NULL ? NULL : (it = (g_object_unref (it), NULL))), _tmp2);
+			return (_tmp2 = TRUE, (it == NULL) ? NULL : (it = (g_object_unref (it), NULL)), _tmp2);
 		}
 	}
-	return (_tmp3 = FALSE, (it == NULL ? NULL : (it = (g_object_unref (it), NULL))), _tmp3);
+	return (_tmp3 = FALSE, (it == NULL) ? NULL : (it = (g_object_unref (it), NULL)), _tmp3);
 }
 
 
 static void gee_hash_map_value_collection_set_map (GeeHashMapValueCollection* self, GeeHashMap* value) {
 	GeeHashMap* _tmp1;
 	GeeHashMap* _tmp0;
-	g_return_if_fail (GEE_HASH_MAP_IS_VALUE_COLLECTION (self));
+	g_return_if_fail (self != NULL);
 	_tmp1 = NULL;
 	_tmp0 = NULL;
-	self->priv->_map = (_tmp1 = (_tmp0 = value, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0))), (self->priv->_map == NULL ? NULL : (self->priv->_map = (g_object_unref (self->priv->_map), NULL))), _tmp1);
-	g_object_notify (((GObject *) (self)), "map");
+	self->priv->_map = (_tmp1 = (_tmp0 = value, (_tmp0 == NULL) ? NULL : g_object_ref (_tmp0)), (self->priv->_map == NULL) ? NULL : (self->priv->_map = (g_object_unref (self->priv->_map), NULL)), _tmp1);
+	g_object_notify ((GObject *) self, "map");
 }
 
 
 static gint gee_hash_map_value_collection_real_get_size (GeeCollection* base) {
 	GeeHashMapValueCollection* self;
-	self = GEE_HASH_MAP_VALUE_COLLECTION (base);
-	return gee_map_get_size (GEE_MAP (self->priv->_map));
+	self = (GeeHashMapValueCollection*) base;
+	return gee_map_get_size ((GeeMap*) self->priv->_map);
 }
 
 
 static void gee_hash_map_value_collection_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	GeeHashMapValueCollection * self;
+	gpointer boxed;
 	self = GEE_HASH_MAP_VALUE_COLLECTION (object);
 	switch (property_id) {
 		case GEE_HASH_MAP_VALUE_COLLECTION_SIZE:
-		g_value_set_int (value, gee_collection_get_size (GEE_COLLECTION (self)));
+		g_value_set_int (value, gee_collection_get_size ((GeeCollection*) self));
 		break;
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -1161,6 +1214,9 @@ static void gee_hash_map_value_collection_set_property (GObject * object, guint
 		case GEE_HASH_MAP_VALUE_COLLECTION_MAP:
 		gee_hash_map_value_collection_set_map (self, g_value_get_object (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 		case GEE_HASH_MAP_VALUE_COLLECTION_K_TYPE:
 		self->priv->k_type = g_value_get_gtype (value);
 		break;
@@ -1179,9 +1235,6 @@ static void gee_hash_map_value_collection_set_property (GObject * object, guint
 		case GEE_HASH_MAP_VALUE_COLLECTION_V_DESTROY_FUNC:
 		self->priv->v_destroy_func = g_value_get_pointer (value);
 		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
 	}
 }
 
@@ -1228,7 +1281,7 @@ static void gee_hash_map_value_collection_instance_init (GeeHashMapValueCollecti
 static void gee_hash_map_value_collection_finalize (GObject* obj) {
 	GeeHashMapValueCollection * self;
 	self = GEE_HASH_MAP_VALUE_COLLECTION (obj);
-	(self->priv->_map == NULL ? NULL : (self->priv->_map = (g_object_unref (self->priv->_map), NULL)));
+	(self->priv->_map == NULL) ? NULL : (self->priv->_map = (g_object_unref (self->priv->_map), NULL));
 	G_OBJECT_CLASS (gee_hash_map_value_collection_parent_class)->finalize (obj);
 }
 
@@ -1251,7 +1304,7 @@ static GeeHashMapValueIterator* gee_hash_map_value_iterator_construct (GType obj
 	GParameter * __params;
 	GParameter * __params_it;
 	GeeHashMapValueIterator * self;
-	g_return_val_if_fail (GEE_IS_HASH_MAP (map), NULL);
+	g_return_val_if_fail (map != NULL, NULL);
 	__params = g_new0 (GParameter, 6);
 	__params_it = __params;
 	__params_it->name = "k-type";
@@ -1296,11 +1349,21 @@ static GeeHashMapValueIterator* gee_hash_map_value_iterator_new (GType k_type, G
 
 static gboolean gee_hash_map_value_iterator_real_next (GeeIterator* base) {
 	GeeHashMapValueIterator * self;
-	self = GEE_HASH_MAP_VALUE_ITERATOR (base);
+	self = (GeeHashMapValueIterator*) base;
 	if (self->priv->_node != NULL) {
 		self->priv->_node = self->priv->_node->next;
 	}
-	while (self->priv->_node == NULL && self->priv->_index + 1 < self->priv->_map->priv->_array_size) {
+	while (TRUE) {
+		gboolean _tmp0;
+		_tmp0 = FALSE;
+		if (self->priv->_node == NULL) {
+			_tmp0 = (self->priv->_index + 1) < self->priv->_map->priv->_array_size;
+		} else {
+			_tmp0 = FALSE;
+		}
+		if (!_tmp0) {
+			break;
+		}
 		self->priv->_index++;
 		self->priv->_node = self->priv->_map->priv->_nodes[self->priv->_index];
 	}
@@ -1311,28 +1374,29 @@ static gboolean gee_hash_map_value_iterator_real_next (GeeIterator* base) {
 static gpointer gee_hash_map_value_iterator_real_get (GeeIterator* base) {
 	GeeHashMapValueIterator * self;
 	gconstpointer _tmp0;
-	self = GEE_HASH_MAP_VALUE_ITERATOR (base);
+	self = (GeeHashMapValueIterator*) base;
 	g_assert (self->priv->_stamp == self->priv->_map->priv->_stamp);
 	g_assert (self->priv->_node != NULL);
 	_tmp0 = NULL;
-	return (_tmp0 = self->priv->_node->value, (_tmp0 == NULL || self->priv->v_dup_func == NULL ? ((gpointer) (_tmp0)) : self->priv->v_dup_func (((gpointer) (_tmp0)))));
+	return (_tmp0 = self->priv->_node->value, ((_tmp0 == NULL) || (self->priv->v_dup_func == NULL)) ? ((gpointer) _tmp0) : self->priv->v_dup_func ((gpointer) _tmp0));
 }
 
 
 static void gee_hash_map_value_iterator_set_map (GeeHashMapValueIterator* self, GeeHashMap* value) {
 	GeeHashMap* _tmp1;
 	GeeHashMap* _tmp0;
-	g_return_if_fail (GEE_HASH_MAP_IS_VALUE_ITERATOR (self));
+	g_return_if_fail (self != NULL);
 	_tmp1 = NULL;
 	_tmp0 = NULL;
-	self->priv->_map = (_tmp1 = (_tmp0 = value, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0))), (self->priv->_map == NULL ? NULL : (self->priv->_map = (g_object_unref (self->priv->_map), NULL))), _tmp1);
+	self->priv->_map = (_tmp1 = (_tmp0 = value, (_tmp0 == NULL) ? NULL : g_object_ref (_tmp0)), (self->priv->_map == NULL) ? NULL : (self->priv->_map = (g_object_unref (self->priv->_map), NULL)), _tmp1);
 	self->priv->_stamp = self->priv->_map->priv->_stamp;
-	g_object_notify (((GObject *) (self)), "map");
+	g_object_notify ((GObject *) self, "map");
 }
 
 
 static void gee_hash_map_value_iterator_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	GeeHashMapValueIterator * self;
+	gpointer boxed;
 	self = GEE_HASH_MAP_VALUE_ITERATOR (object);
 	switch (property_id) {
 		default:
@@ -1349,6 +1413,9 @@ static void gee_hash_map_value_iterator_set_property (GObject * object, guint pr
 		case GEE_HASH_MAP_VALUE_ITERATOR_MAP:
 		gee_hash_map_value_iterator_set_map (self, g_value_get_object (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 		case GEE_HASH_MAP_VALUE_ITERATOR_K_TYPE:
 		self->priv->k_type = g_value_get_gtype (value);
 		break;
@@ -1367,9 +1434,6 @@ static void gee_hash_map_value_iterator_set_property (GObject * object, guint pr
 		case GEE_HASH_MAP_VALUE_ITERATOR_V_DESTROY_FUNC:
 		self->priv->v_destroy_func = g_value_get_pointer (value);
 		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
 	}
 }
 
@@ -1406,7 +1470,7 @@ static void gee_hash_map_value_iterator_instance_init (GeeHashMapValueIterator *
 static void gee_hash_map_value_iterator_finalize (GObject* obj) {
 	GeeHashMapValueIterator * self;
 	self = GEE_HASH_MAP_VALUE_ITERATOR (obj);
-	(self->priv->_map == NULL ? NULL : (self->priv->_map = (g_object_unref (self->priv->_map), NULL)));
+	(self->priv->_map == NULL) ? NULL : (self->priv->_map = (g_object_unref (self->priv->_map), NULL));
 	G_OBJECT_CLASS (gee_hash_map_value_iterator_parent_class)->finalize (obj);
 }
 
@@ -1425,10 +1489,11 @@ static GType gee_hash_map_value_iterator_get_type (void) {
 
 static void gee_hash_map_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	GeeHashMap * self;
+	gpointer boxed;
 	self = GEE_HASH_MAP (object);
 	switch (property_id) {
 		case GEE_HASH_MAP_SIZE:
-		g_value_set_int (value, gee_map_get_size (GEE_MAP (self)));
+		g_value_set_int (value, gee_map_get_size ((GeeMap*) self));
 		break;
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -1450,6 +1515,9 @@ static void gee_hash_map_set_property (GObject * object, guint property_id, cons
 		case GEE_HASH_MAP_VALUE_EQUAL_FUNC:
 		gee_hash_map_set_value_equal_func (self, g_value_get_pointer (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 		case GEE_HASH_MAP_K_TYPE:
 		self->priv->k_type = g_value_get_gtype (value);
 		break;
@@ -1468,9 +1536,6 @@ static void gee_hash_map_set_property (GObject * object, guint property_id, cons
 		case GEE_HASH_MAP_V_DESTROY_FUNC:
 		self->priv->v_destroy_func = g_value_get_pointer (value);
 		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
 	}
 }
 
@@ -1518,9 +1583,9 @@ static void gee_hash_map_finalize (GObject* obj) {
 	GeeHashMap * self;
 	self = GEE_HASH_MAP (obj);
 	{
-		gee_map_clear (GEE_MAP (self));
+		gee_map_clear ((GeeMap*) self);
 	}
-	self->priv->_nodes = (_vala_array_free (self->priv->_nodes, self->priv->_nodes_length1, ((GDestroyNotify) (gee_hash_map_node_free))), NULL);
+	self->priv->_nodes = (_vala_array_free (self->priv->_nodes, self->priv->_nodes_length1, (GDestroyNotify) gee_hash_map_node_free), NULL);
 	G_OBJECT_CLASS (gee_hash_map_parent_class)->finalize (obj);
 }
 
@@ -1538,16 +1603,12 @@ GType gee_hash_map_get_type (void) {
 
 
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
-	if (array != NULL && destroy_func != NULL) {
+	if ((array != NULL) && (destroy_func != NULL)) {
 		int i;
-		if (array_length >= 0)
 		for (i = 0; i < array_length; i = i + 1) {
-			if (((gpointer*) (array))[i] != NULL)
-			destroy_func (((gpointer*) (array))[i]);
-		}
-		else
-		for (i = 0; ((gpointer*) (array))[i] != NULL; i = i + 1) {
-			destroy_func (((gpointer*) (array))[i]);
+			if (((gpointer*) array)[i] != NULL) {
+				destroy_func (((gpointer*) array)[i]);
+			}
 		}
 	}
 	g_free (array);
