@@ -59,6 +59,7 @@ struct _GeeHashSetPrivate {
 	gint _nnodes;
 	GeeHashSetNode** _nodes;
 	gint _nodes_length1;
+	gint _nodes_size;
 	gint _stamp;
 	GHashFunc _hash_func;
 	GEqualFunc _equal_func;
@@ -165,11 +166,28 @@ GeeHashSet* gee_hash_set_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyN
 static GeeHashSetNode** gee_hash_set_lookup_node (GeeHashSet* self, gconstpointer key) {
 	guint hash_value;
 	GeeHashSetNode** node;
-	g_return_val_if_fail (GEE_IS_HASH_SET (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	hash_value = self->priv->_hash_func (key);
 	node = &self->priv->_nodes[hash_value % self->priv->_array_size];
-	while (((*node)) != NULL && (hash_value != ((*node))->key_hash || !self->priv->_equal_func (((*node))->key, key))) {
-		node = &(((*node))->next);
+	while (TRUE) {
+		gboolean _tmp0;
+		_tmp0 = FALSE;
+		if ((*node) != NULL) {
+			gboolean _tmp1;
+			_tmp1 = FALSE;
+			if (hash_value != (*node)->key_hash) {
+				_tmp1 = TRUE;
+			} else {
+				_tmp1 = !self->priv->_equal_func ((*node)->key, key);
+			}
+			_tmp0 = (_tmp1);
+		} else {
+			_tmp0 = FALSE;
+		}
+		if (!_tmp0) {
+			break;
+		}
+		node = &((*node)->next);
 	}
 	return node;
 }
@@ -178,7 +196,7 @@ static GeeHashSetNode** gee_hash_set_lookup_node (GeeHashSet* self, gconstpointe
 static gboolean gee_hash_set_real_contains (GeeCollection* base, gconstpointer key) {
 	GeeHashSet * self;
 	GeeHashSetNode** node;
-	self = GEE_HASH_SET (base);
+	self = (GeeHashSet*) base;
 	node = gee_hash_set_lookup_node (self, key);
 	return ((*node) != NULL);
 }
@@ -186,22 +204,22 @@ static gboolean gee_hash_set_real_contains (GeeCollection* base, gconstpointer k
 
 static GType gee_hash_set_real_get_element_type (GeeIterable* base) {
 	GeeHashSet * self;
-	self = GEE_HASH_SET (base);
+	self = (GeeHashSet*) base;
 	return self->priv->g_type;
 }
 
 
 static GeeIterator* gee_hash_set_real_iterator (GeeIterable* base) {
 	GeeHashSet * self;
-	self = GEE_HASH_SET (base);
-	return GEE_ITERATOR (gee_hash_set_iterator_new (self->priv->g_type, ((GBoxedCopyFunc) (self->priv->g_dup_func)), self->priv->g_destroy_func, self));
+	self = (GeeHashSet*) base;
+	return (GeeIterator*) gee_hash_set_iterator_new (self->priv->g_type, (GBoxedCopyFunc) self->priv->g_dup_func, self->priv->g_destroy_func, self);
 }
 
 
 static gboolean gee_hash_set_real_add (GeeCollection* base, gconstpointer key) {
 	GeeHashSet * self;
 	GeeHashSetNode** node;
-	self = GEE_HASH_SET (base);
+	self = (GeeHashSet*) base;
 	node = gee_hash_set_lookup_node (self, key);
 	if ((*node) != NULL) {
 		return FALSE;
@@ -210,7 +228,7 @@ static gboolean gee_hash_set_real_add (GeeCollection* base, gconstpointer key) {
 		gconstpointer _tmp1;
 		hash_value = self->priv->_hash_func (key);
 		_tmp1 = NULL;
-		(*node) = gee_hash_set_node_new ((_tmp1 = key, (_tmp1 == NULL || self->priv->g_dup_func == NULL ? ((gpointer) (_tmp1)) : self->priv->g_dup_func (((gpointer) (_tmp1))))), hash_value);
+		*node = gee_hash_set_node_new ((_tmp1 = key, ((_tmp1 == NULL) || (self->priv->g_dup_func == NULL)) ? ((gpointer) _tmp1) : self->priv->g_dup_func ((gpointer) _tmp1)), hash_value);
 		self->priv->_nnodes++;
 		gee_hash_set_resize (self);
 		self->priv->_stamp++;
@@ -222,13 +240,13 @@ static gboolean gee_hash_set_real_add (GeeCollection* base, gconstpointer key) {
 static gboolean gee_hash_set_real_remove (GeeCollection* base, gconstpointer key) {
 	GeeHashSet * self;
 	GeeHashSetNode** node;
-	self = GEE_HASH_SET (base);
+	self = (GeeHashSet*) base;
 	node = gee_hash_set_lookup_node (self, key);
 	if ((*node) != NULL) {
 		gpointer _tmp0;
 		_tmp0 = NULL;
-		((*node))->key = (_tmp0 = NULL, (((*node))->key == NULL || self->priv->g_destroy_func == NULL ? NULL : (((*node))->key = (self->priv->g_destroy_func (((*node))->key), NULL))), _tmp0);
-		(*node) = ((*node))->next;
+		(*node)->key = (_tmp0 = NULL, (((*node)->key == NULL) || (self->priv->g_destroy_func == NULL)) ? NULL : ((*node)->key = (self->priv->g_destroy_func ((*node)->key), NULL)), _tmp0);
+		*node = (*node)->next;
 		self->priv->_nnodes--;
 		gee_hash_set_resize (self);
 		self->priv->_stamp++;
@@ -240,7 +258,7 @@ static gboolean gee_hash_set_real_remove (GeeCollection* base, gconstpointer key
 
 static void gee_hash_set_real_clear (GeeCollection* base) {
 	GeeHashSet * self;
-	self = GEE_HASH_SET (base);
+	self = (GeeHashSet*) base;
 	{
 		gint i;
 		i = 0;
@@ -258,13 +276,13 @@ static void gee_hash_set_real_clear (GeeCollection* base) {
 				_tmp1 = NULL;
 				next = (_tmp1 = node->next, node->next = NULL, _tmp1);
 				_tmp2 = NULL;
-				node->key = (_tmp2 = NULL, (node->key == NULL || self->priv->g_destroy_func == NULL ? NULL : (node->key = (self->priv->g_destroy_func (node->key), NULL))), _tmp2);
+				node->key = (_tmp2 = NULL, ((node->key == NULL) || (self->priv->g_destroy_func == NULL)) ? NULL : (node->key = (self->priv->g_destroy_func (node->key), NULL)), _tmp2);
 				_tmp4 = NULL;
 				_tmp3 = NULL;
-				node = (_tmp4 = (_tmp3 = next, next = NULL, _tmp3), (node == NULL ? NULL : (node = (gee_hash_set_node_free (node), NULL))), _tmp4);
-				(next == NULL ? NULL : (next = (gee_hash_set_node_free (next), NULL)));
+				node = (_tmp4 = (_tmp3 = next, next = NULL, _tmp3), (node == NULL) ? NULL : (node = (gee_hash_set_node_free (node), NULL)), _tmp4);
+				(next == NULL) ? NULL : (next = (gee_hash_set_node_free (next), NULL));
 			}
-			(node == NULL ? NULL : (node = (gee_hash_set_node_free (node), NULL)));
+			(node == NULL) ? NULL : (node = (gee_hash_set_node_free (node), NULL));
 		}
 	}
 	self->priv->_nnodes = 0;
@@ -273,84 +291,106 @@ static void gee_hash_set_real_clear (GeeCollection* base) {
 
 
 static void gee_hash_set_resize (GeeHashSet* self) {
-	g_return_if_fail (GEE_IS_HASH_SET (self));
-	if ((self->priv->_array_size >= 3 * self->priv->_nnodes && self->priv->_array_size >= GEE_HASH_SET_MIN_SIZE) || (3 * self->priv->_array_size <= self->priv->_nnodes && self->priv->_array_size < GEE_HASH_SET_MAX_SIZE)) {
+	gboolean _tmp0;
+	gboolean _tmp1;
+	g_return_if_fail (self != NULL);
+	_tmp0 = FALSE;
+	_tmp1 = FALSE;
+	if (self->priv->_array_size >= (3 * self->priv->_nnodes)) {
+		_tmp1 = self->priv->_array_size >= GEE_HASH_SET_MIN_SIZE;
+	} else {
+		_tmp1 = FALSE;
+	}
+	if ((_tmp1)) {
+		_tmp0 = TRUE;
+	} else {
+		gboolean _tmp2;
+		_tmp2 = FALSE;
+		if ((3 * self->priv->_array_size) <= self->priv->_nnodes) {
+			_tmp2 = self->priv->_array_size < GEE_HASH_SET_MAX_SIZE;
+		} else {
+			_tmp2 = FALSE;
+		}
+		_tmp0 = (_tmp2);
+	}
+	if (_tmp0) {
 		gint new_array_size;
-		GeeHashSetNode** _tmp0;
+		GeeHashSetNode** _tmp3;
+		gint new_nodes_size;
 		gint new_nodes_length1;
 		GeeHashSetNode** new_nodes;
-		GeeHashSetNode** _tmp12;
-		GeeHashSetNode** _tmp11;
-		new_array_size = ((gint) (g_spaced_primes_closest (((guint) (self->priv->_nnodes)))));
+		GeeHashSetNode** _tmp15;
+		GeeHashSetNode** _tmp14;
+		new_array_size = (gint) g_spaced_primes_closest ((guint) self->priv->_nnodes);
 		new_array_size = CLAMP (new_array_size, GEE_HASH_SET_MIN_SIZE, GEE_HASH_SET_MAX_SIZE);
-		_tmp0 = NULL;
-		new_nodes = (_tmp0 = g_new0 (GeeHashSetNode*, new_array_size + 1), new_nodes_length1 = new_array_size, _tmp0);
+		_tmp3 = NULL;
+		new_nodes = (_tmp3 = g_new0 (GeeHashSetNode*, new_array_size + 1), new_nodes_length1 = new_array_size, new_nodes_size = new_nodes_length1, _tmp3);
 		{
 			gint i;
 			i = 0;
 			for (; i < self->priv->_array_size; i++) {
 				GeeHashSetNode* node;
 				GeeHashSetNode* next;
+				GeeHashSetNode* _tmp7;
+				GeeHashSetNode* _tmp6;
+				GeeHashSetNode* _tmp5;
 				GeeHashSetNode* _tmp4;
-				GeeHashSetNode* _tmp3;
-				GeeHashSetNode* _tmp2;
-				GeeHashSetNode* _tmp1;
 				node = NULL;
 				next = NULL;
+				_tmp7 = NULL;
+				_tmp6 = NULL;
+				_tmp5 = NULL;
 				_tmp4 = NULL;
-				_tmp3 = NULL;
-				_tmp2 = NULL;
-				_tmp1 = NULL;
-				for (node = (_tmp2 = (_tmp1 = self->priv->_nodes[i], self->priv->_nodes[i] = NULL, _tmp1), (node == NULL ? NULL : (node = (gee_hash_set_node_free (node), NULL))), _tmp2); node != NULL; node = (_tmp4 = (_tmp3 = next, next = NULL, _tmp3), (node == NULL ? NULL : (node = (gee_hash_set_node_free (node), NULL))), _tmp4)) {
-					GeeHashSetNode* _tmp6;
-					GeeHashSetNode* _tmp5;
-					guint hash_val;
-					GeeHashSetNode* _tmp8;
-					GeeHashSetNode* _tmp7;
-					GeeHashSetNode* _tmp10;
+				for (node = (_tmp5 = (_tmp4 = self->priv->_nodes[i], self->priv->_nodes[i] = NULL, _tmp4), (node == NULL) ? NULL : (node = (gee_hash_set_node_free (node), NULL)), _tmp5); node != NULL; node = (_tmp7 = (_tmp6 = next, next = NULL, _tmp6), (node == NULL) ? NULL : (node = (gee_hash_set_node_free (node), NULL)), _tmp7)) {
 					GeeHashSetNode* _tmp9;
-					_tmp6 = NULL;
-					_tmp5 = NULL;
-					next = (_tmp6 = (_tmp5 = node->next, node->next = NULL, _tmp5), (next == NULL ? NULL : (next = (gee_hash_set_node_free (next), NULL))), _tmp6);
-					hash_val = node->key_hash % new_array_size;
-					_tmp8 = NULL;
-					_tmp7 = NULL;
-					node->next = (_tmp8 = (_tmp7 = new_nodes[hash_val], new_nodes[hash_val] = NULL, _tmp7), (node->next == NULL ? NULL : (node->next = (gee_hash_set_node_free (node->next), NULL))), _tmp8);
-					_tmp10 = NULL;
+					GeeHashSetNode* _tmp8;
+					guint hash_val;
+					GeeHashSetNode* _tmp11;
+					GeeHashSetNode* _tmp10;
+					GeeHashSetNode* _tmp13;
+					GeeHashSetNode* _tmp12;
 					_tmp9 = NULL;
-					new_nodes[hash_val] = (_tmp10 = (_tmp9 = node, node = NULL, _tmp9), (new_nodes[hash_val] == NULL ? NULL : (new_nodes[hash_val] = (gee_hash_set_node_free (new_nodes[hash_val]), NULL))), _tmp10);
+					_tmp8 = NULL;
+					next = (_tmp9 = (_tmp8 = node->next, node->next = NULL, _tmp8), (next == NULL) ? NULL : (next = (gee_hash_set_node_free (next), NULL)), _tmp9);
+					hash_val = node->key_hash % new_array_size;
+					_tmp11 = NULL;
+					_tmp10 = NULL;
+					node->next = (_tmp11 = (_tmp10 = new_nodes[hash_val], new_nodes[hash_val] = NULL, _tmp10), (node->next == NULL) ? NULL : (node->next = (gee_hash_set_node_free (node->next), NULL)), _tmp11);
+					_tmp13 = NULL;
+					_tmp12 = NULL;
+					new_nodes[hash_val] = (_tmp13 = (_tmp12 = node, node = NULL, _tmp12), (new_nodes[hash_val] == NULL) ? NULL : (new_nodes[hash_val] = (gee_hash_set_node_free (new_nodes[hash_val]), NULL)), _tmp13);
 				}
-				(node == NULL ? NULL : (node = (gee_hash_set_node_free (node), NULL)));
-				(next == NULL ? NULL : (next = (gee_hash_set_node_free (next), NULL)));
+				(node == NULL) ? NULL : (node = (gee_hash_set_node_free (node), NULL));
+				(next == NULL) ? NULL : (next = (gee_hash_set_node_free (next), NULL));
 			}
 		}
-		_tmp12 = NULL;
-		_tmp11 = NULL;
-		self->priv->_nodes = (_tmp12 = (_tmp11 = new_nodes, new_nodes = NULL, _tmp11), (self->priv->_nodes = (_vala_array_free (self->priv->_nodes, self->priv->_nodes_length1, ((GDestroyNotify) (gee_hash_set_node_free))), NULL)), self->priv->_nodes_length1 = new_nodes_length1, _tmp12);
+		_tmp15 = NULL;
+		_tmp14 = NULL;
+		self->priv->_nodes = (_tmp15 = (_tmp14 = new_nodes, new_nodes = NULL, _tmp14), self->priv->_nodes = (_vala_array_free (self->priv->_nodes, self->priv->_nodes_length1, (GDestroyNotify) gee_hash_set_node_free), NULL), self->priv->_nodes_length1 = new_nodes_length1, self->priv->_nodes_size = self->priv->_nodes_length1, _tmp15);
 		self->priv->_array_size = new_array_size;
-		new_nodes = (_vala_array_free (new_nodes, new_nodes_length1, ((GDestroyNotify) (gee_hash_set_node_free))), NULL);
+		new_nodes = (_vala_array_free (new_nodes, new_nodes_length1, (GDestroyNotify) gee_hash_set_node_free), NULL);
 	}
 }
 
 
 static gint gee_hash_set_real_get_size (GeeCollection* base) {
 	GeeHashSet* self;
-	self = GEE_HASH_SET (base);
+	self = (GeeHashSet*) base;
 	return self->priv->_nnodes;
 }
 
 
 void gee_hash_set_set_hash_func (GeeHashSet* self, GHashFunc value) {
-	g_return_if_fail (GEE_IS_HASH_SET (self));
+	g_return_if_fail (self != NULL);
 	self->priv->_hash_func = value;
-	g_object_notify (((GObject *) (self)), "hash-func");
+	g_object_notify ((GObject *) self, "hash-func");
 }
 
 
 void gee_hash_set_set_equal_func (GeeHashSet* self, GEqualFunc value) {
-	g_return_if_fail (GEE_IS_HASH_SET (self));
+	g_return_if_fail (self != NULL);
 	self->priv->_equal_func = value;
-	g_object_notify (((GObject *) (self)), "equal-func");
+	g_object_notify ((GObject *) self, "equal-func");
 }
 
 
@@ -367,7 +407,7 @@ static GObject * gee_hash_set_constructor (GType type, guint n_construct_propert
 		GeeHashSetNode** _tmp0;
 		self->priv->_array_size = GEE_HASH_SET_MIN_SIZE;
 		_tmp0 = NULL;
-		self->priv->_nodes = (_tmp0 = g_new0 (GeeHashSetNode*, self->priv->_array_size + 1), (self->priv->_nodes = (_vala_array_free (self->priv->_nodes, self->priv->_nodes_length1, ((GDestroyNotify) (gee_hash_set_node_free))), NULL)), self->priv->_nodes_length1 = self->priv->_array_size, _tmp0);
+		self->priv->_nodes = (_tmp0 = g_new0 (GeeHashSetNode*, self->priv->_array_size + 1), self->priv->_nodes = (_vala_array_free (self->priv->_nodes, self->priv->_nodes_length1, (GDestroyNotify) gee_hash_set_node_free), NULL), self->priv->_nodes_length1 = self->priv->_array_size, self->priv->_nodes_size = self->priv->_nodes_length1, _tmp0);
 	}
 	return obj;
 }
@@ -390,7 +430,7 @@ static void gee_hash_set_node_instance_init (GeeHashSetNode * self) {
 
 
 static void gee_hash_set_node_free (GeeHashSetNode* self) {
-	(self->next == NULL ? NULL : (self->next = (gee_hash_set_node_free (self->next), NULL)));
+	(self->next == NULL) ? NULL : (self->next = (gee_hash_set_node_free (self->next), NULL));
 	g_slice_free (GeeHashSetNode, self);
 }
 
@@ -399,7 +439,7 @@ static GeeHashSetIterator* gee_hash_set_iterator_construct (GType object_type, G
 	GParameter * __params;
 	GParameter * __params_it;
 	GeeHashSetIterator * self;
-	g_return_val_if_fail (GEE_IS_HASH_SET (set), NULL);
+	g_return_val_if_fail (set != NULL, NULL);
 	__params = g_new0 (GParameter, 3);
 	__params_it = __params;
 	__params_it->name = "g-type";
@@ -432,11 +472,21 @@ static GeeHashSetIterator* gee_hash_set_iterator_new (GType g_type, GBoxedCopyFu
 
 static gboolean gee_hash_set_iterator_real_next (GeeIterator* base) {
 	GeeHashSetIterator * self;
-	self = GEE_HASH_SET_ITERATOR (base);
+	self = (GeeHashSetIterator*) base;
 	if (self->priv->_node != NULL) {
 		self->priv->_node = self->priv->_node->next;
 	}
-	while (self->priv->_node == NULL && self->priv->_index + 1 < self->priv->_set->priv->_array_size) {
+	while (TRUE) {
+		gboolean _tmp0;
+		_tmp0 = FALSE;
+		if (self->priv->_node == NULL) {
+			_tmp0 = (self->priv->_index + 1) < self->priv->_set->priv->_array_size;
+		} else {
+			_tmp0 = FALSE;
+		}
+		if (!_tmp0) {
+			break;
+		}
 		self->priv->_index++;
 		self->priv->_node = self->priv->_set->priv->_nodes[self->priv->_index];
 	}
@@ -447,28 +497,29 @@ static gboolean gee_hash_set_iterator_real_next (GeeIterator* base) {
 static gpointer gee_hash_set_iterator_real_get (GeeIterator* base) {
 	GeeHashSetIterator * self;
 	gconstpointer _tmp0;
-	self = GEE_HASH_SET_ITERATOR (base);
+	self = (GeeHashSetIterator*) base;
 	g_assert (self->priv->_stamp == self->priv->_set->priv->_stamp);
 	g_assert (self->priv->_node != NULL);
 	_tmp0 = NULL;
-	return (_tmp0 = self->priv->_node->key, (_tmp0 == NULL || self->priv->g_dup_func == NULL ? ((gpointer) (_tmp0)) : self->priv->g_dup_func (((gpointer) (_tmp0)))));
+	return (_tmp0 = self->priv->_node->key, ((_tmp0 == NULL) || (self->priv->g_dup_func == NULL)) ? ((gpointer) _tmp0) : self->priv->g_dup_func ((gpointer) _tmp0));
 }
 
 
 static void gee_hash_set_iterator_set_set (GeeHashSetIterator* self, GeeHashSet* value) {
 	GeeHashSet* _tmp1;
 	GeeHashSet* _tmp0;
-	g_return_if_fail (GEE_HASH_SET_IS_ITERATOR (self));
+	g_return_if_fail (self != NULL);
 	_tmp1 = NULL;
 	_tmp0 = NULL;
-	self->priv->_set = (_tmp1 = (_tmp0 = value, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0))), (self->priv->_set == NULL ? NULL : (self->priv->_set = (g_object_unref (self->priv->_set), NULL))), _tmp1);
+	self->priv->_set = (_tmp1 = (_tmp0 = value, (_tmp0 == NULL) ? NULL : g_object_ref (_tmp0)), (self->priv->_set == NULL) ? NULL : (self->priv->_set = (g_object_unref (self->priv->_set), NULL)), _tmp1);
 	self->priv->_stamp = self->priv->_set->priv->_stamp;
-	g_object_notify (((GObject *) (self)), "set");
+	g_object_notify ((GObject *) self, "set");
 }
 
 
 static void gee_hash_set_iterator_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	GeeHashSetIterator * self;
+	gpointer boxed;
 	self = GEE_HASH_SET_ITERATOR (object);
 	switch (property_id) {
 		default:
@@ -485,6 +536,9 @@ static void gee_hash_set_iterator_set_property (GObject * object, guint property
 		case GEE_HASH_SET_ITERATOR_SET:
 		gee_hash_set_iterator_set_set (self, g_value_get_object (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 		case GEE_HASH_SET_ITERATOR_G_TYPE:
 		self->priv->g_type = g_value_get_gtype (value);
 		break;
@@ -494,9 +548,6 @@ static void gee_hash_set_iterator_set_property (GObject * object, guint property
 		case GEE_HASH_SET_ITERATOR_G_DESTROY_FUNC:
 		self->priv->g_destroy_func = g_value_get_pointer (value);
 		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
 	}
 }
 
@@ -531,7 +582,7 @@ static void gee_hash_set_iterator_instance_init (GeeHashSetIterator * self) {
 static void gee_hash_set_iterator_finalize (GObject* obj) {
 	GeeHashSetIterator * self;
 	self = GEE_HASH_SET_ITERATOR (obj);
-	(self->priv->_set == NULL ? NULL : (self->priv->_set = (g_object_unref (self->priv->_set), NULL)));
+	(self->priv->_set == NULL) ? NULL : (self->priv->_set = (g_object_unref (self->priv->_set), NULL));
 	G_OBJECT_CLASS (gee_hash_set_iterator_parent_class)->finalize (obj);
 }
 
@@ -550,10 +601,11 @@ static GType gee_hash_set_iterator_get_type (void) {
 
 static void gee_hash_set_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	GeeHashSet * self;
+	gpointer boxed;
 	self = GEE_HASH_SET (object);
 	switch (property_id) {
 		case GEE_HASH_SET_SIZE:
-		g_value_set_int (value, gee_collection_get_size (GEE_COLLECTION (self)));
+		g_value_set_int (value, gee_collection_get_size ((GeeCollection*) self));
 		break;
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -572,6 +624,9 @@ static void gee_hash_set_set_property (GObject * object, guint property_id, cons
 		case GEE_HASH_SET_EQUAL_FUNC:
 		gee_hash_set_set_equal_func (self, g_value_get_pointer (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 		case GEE_HASH_SET_G_TYPE:
 		self->priv->g_type = g_value_get_gtype (value);
 		break;
@@ -581,9 +636,6 @@ static void gee_hash_set_set_property (GObject * object, guint property_id, cons
 		case GEE_HASH_SET_G_DESTROY_FUNC:
 		self->priv->g_destroy_func = g_value_get_pointer (value);
 		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
 	}
 }
 
@@ -636,9 +688,9 @@ static void gee_hash_set_finalize (GObject* obj) {
 	GeeHashSet * self;
 	self = GEE_HASH_SET (obj);
 	{
-		gee_collection_clear (GEE_COLLECTION (self));
+		gee_collection_clear ((GeeCollection*) self);
 	}
-	self->priv->_nodes = (_vala_array_free (self->priv->_nodes, self->priv->_nodes_length1, ((GDestroyNotify) (gee_hash_set_node_free))), NULL);
+	self->priv->_nodes = (_vala_array_free (self->priv->_nodes, self->priv->_nodes_length1, (GDestroyNotify) gee_hash_set_node_free), NULL);
 	G_OBJECT_CLASS (gee_hash_set_parent_class)->finalize (obj);
 }
 
@@ -660,16 +712,12 @@ GType gee_hash_set_get_type (void) {
 
 
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
-	if (array != NULL && destroy_func != NULL) {
+	if ((array != NULL) && (destroy_func != NULL)) {
 		int i;
-		if (array_length >= 0)
 		for (i = 0; i < array_length; i = i + 1) {
-			if (((gpointer*) (array))[i] != NULL)
-			destroy_func (((gpointer*) (array))[i]);
-		}
-		else
-		for (i = 0; ((gpointer*) (array))[i] != NULL; i = i + 1) {
-			destroy_func (((gpointer*) (array))[i]);
+			if (((gpointer*) array)[i] != NULL) {
+				destroy_func (((gpointer*) array)[i]);
+			}
 		}
 	}
 	g_free (array);
