@@ -98,7 +98,6 @@ GeeReadOnlyCollection* gee_read_only_collection_construct (GType object_type, GT
 	GParameter * __params;
 	GParameter * __params_it;
 	GeeReadOnlyCollection * self;
-	g_return_val_if_fail (collection == NULL || GEE_IS_COLLECTION (collection), NULL);
 	__params = g_new0 (GParameter, 3);
 	__params_it = __params;
 	__params_it->name = "g-type";
@@ -131,24 +130,24 @@ GeeReadOnlyCollection* gee_read_only_collection_new (GType g_type, GBoxedCopyFun
 
 static GType gee_read_only_collection_real_get_element_type (GeeIterable* base) {
 	GeeReadOnlyCollection * self;
-	self = GEE_READ_ONLY_COLLECTION (base);
+	self = (GeeReadOnlyCollection*) base;
 	return self->priv->g_type;
 }
 
 
 static GeeIterator* gee_read_only_collection_real_iterator (GeeIterable* base) {
 	GeeReadOnlyCollection * self;
-	self = GEE_READ_ONLY_COLLECTION (base);
+	self = (GeeReadOnlyCollection*) base;
 	if (self->priv->_collection == NULL) {
-		return GEE_ITERATOR (gee_read_only_collection_iterator_new (self->priv->g_type, ((GBoxedCopyFunc) (self->priv->g_dup_func)), self->priv->g_destroy_func));
+		return (GeeIterator*) gee_read_only_collection_iterator_new (self->priv->g_type, (GBoxedCopyFunc) self->priv->g_dup_func, self->priv->g_destroy_func);
 	}
-	return gee_iterable_iterator (GEE_ITERABLE (self->priv->_collection));
+	return gee_iterable_iterator ((GeeIterable*) self->priv->_collection);
 }
 
 
 static gboolean gee_read_only_collection_real_contains (GeeCollection* base, gconstpointer item) {
 	GeeReadOnlyCollection * self;
-	self = GEE_READ_ONLY_COLLECTION (base);
+	self = (GeeReadOnlyCollection*) base;
 	if (self->priv->_collection == NULL) {
 		return FALSE;
 	}
@@ -158,28 +157,28 @@ static gboolean gee_read_only_collection_real_contains (GeeCollection* base, gco
 
 static gboolean gee_read_only_collection_real_add (GeeCollection* base, gconstpointer item) {
 	GeeReadOnlyCollection * self;
-	self = GEE_READ_ONLY_COLLECTION (base);
+	self = (GeeReadOnlyCollection*) base;
 	g_assert_not_reached ();
 }
 
 
 static gboolean gee_read_only_collection_real_remove (GeeCollection* base, gconstpointer item) {
 	GeeReadOnlyCollection * self;
-	self = GEE_READ_ONLY_COLLECTION (base);
+	self = (GeeReadOnlyCollection*) base;
 	g_assert_not_reached ();
 }
 
 
 static void gee_read_only_collection_real_clear (GeeCollection* base) {
 	GeeReadOnlyCollection * self;
-	self = GEE_READ_ONLY_COLLECTION (base);
+	self = (GeeReadOnlyCollection*) base;
 	g_assert_not_reached ();
 }
 
 
 static gint gee_read_only_collection_real_get_size (GeeCollection* base) {
 	GeeReadOnlyCollection* self;
-	self = GEE_READ_ONLY_COLLECTION (base);
+	self = (GeeReadOnlyCollection*) base;
 	return gee_collection_get_size (self->priv->_collection);
 }
 
@@ -187,24 +186,24 @@ static gint gee_read_only_collection_real_get_size (GeeCollection* base) {
 void gee_read_only_collection_set_collection (GeeReadOnlyCollection* self, GeeCollection* value) {
 	GeeCollection* _tmp1;
 	GeeCollection* _tmp0;
-	g_return_if_fail (GEE_IS_READ_ONLY_COLLECTION (self));
+	g_return_if_fail (self != NULL);
 	_tmp1 = NULL;
 	_tmp0 = NULL;
-	self->priv->_collection = (_tmp1 = (_tmp0 = value, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0))), (self->priv->_collection == NULL ? NULL : (self->priv->_collection = (g_object_unref (self->priv->_collection), NULL))), _tmp1);
-	g_object_notify (((GObject *) (self)), "collection");
+	self->priv->_collection = (_tmp1 = (_tmp0 = value, (_tmp0 == NULL) ? NULL : g_object_ref (_tmp0)), (self->priv->_collection == NULL) ? NULL : (self->priv->_collection = (g_object_unref (self->priv->_collection), NULL)), _tmp1);
+	g_object_notify ((GObject *) self, "collection");
 }
 
 
 static gboolean gee_read_only_collection_iterator_real_next (GeeIterator* base) {
 	GeeReadOnlyCollectionIterator * self;
-	self = GEE_READ_ONLY_COLLECTION_ITERATOR (base);
+	self = (GeeReadOnlyCollectionIterator*) base;
 	return FALSE;
 }
 
 
 static gpointer gee_read_only_collection_iterator_real_get (GeeIterator* base) {
 	GeeReadOnlyCollectionIterator * self;
-	self = GEE_READ_ONLY_COLLECTION_ITERATOR (base);
+	self = (GeeReadOnlyCollectionIterator*) base;
 	return NULL;
 }
 
@@ -244,6 +243,7 @@ static GeeReadOnlyCollectionIterator* gee_read_only_collection_iterator_new (GTy
 
 static void gee_read_only_collection_iterator_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	GeeReadOnlyCollectionIterator * self;
+	gpointer boxed;
 	self = GEE_READ_ONLY_COLLECTION_ITERATOR (object);
 	switch (property_id) {
 		default:
@@ -257,6 +257,9 @@ static void gee_read_only_collection_iterator_set_property (GObject * object, gu
 	GeeReadOnlyCollectionIterator * self;
 	self = GEE_READ_ONLY_COLLECTION_ITERATOR (object);
 	switch (property_id) {
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 		case GEE_READ_ONLY_COLLECTION_ITERATOR_G_TYPE:
 		self->priv->g_type = g_value_get_gtype (value);
 		break;
@@ -266,9 +269,6 @@ static void gee_read_only_collection_iterator_set_property (GObject * object, gu
 		case GEE_READ_ONLY_COLLECTION_ITERATOR_G_DESTROY_FUNC:
 		self->priv->g_destroy_func = g_value_get_pointer (value);
 		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
 	}
 }
 
@@ -310,10 +310,11 @@ static GType gee_read_only_collection_iterator_get_type (void) {
 
 static void gee_read_only_collection_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	GeeReadOnlyCollection * self;
+	gpointer boxed;
 	self = GEE_READ_ONLY_COLLECTION (object);
 	switch (property_id) {
 		case GEE_READ_ONLY_COLLECTION_SIZE:
-		g_value_set_int (value, gee_collection_get_size (GEE_COLLECTION (self)));
+		g_value_set_int (value, gee_collection_get_size ((GeeCollection*) self));
 		break;
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -329,6 +330,9 @@ static void gee_read_only_collection_set_property (GObject * object, guint prope
 		case GEE_READ_ONLY_COLLECTION_COLLECTION:
 		gee_read_only_collection_set_collection (self, g_value_get_object (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 		case GEE_READ_ONLY_COLLECTION_G_TYPE:
 		self->priv->g_type = g_value_get_gtype (value);
 		break;
@@ -338,9 +342,6 @@ static void gee_read_only_collection_set_property (GObject * object, guint prope
 		case GEE_READ_ONLY_COLLECTION_G_DESTROY_FUNC:
 		self->priv->g_destroy_func = g_value_get_pointer (value);
 		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
 	}
 }
 
@@ -384,7 +385,7 @@ static void gee_read_only_collection_instance_init (GeeReadOnlyCollection * self
 static void gee_read_only_collection_finalize (GObject* obj) {
 	GeeReadOnlyCollection * self;
 	self = GEE_READ_ONLY_COLLECTION (obj);
-	(self->priv->_collection == NULL ? NULL : (self->priv->_collection = (g_object_unref (self->priv->_collection), NULL)));
+	(self->priv->_collection == NULL) ? NULL : (self->priv->_collection = (g_object_unref (self->priv->_collection), NULL));
 	G_OBJECT_CLASS (gee_read_only_collection_parent_class)->finalize (obj);
 }
 
