@@ -72,6 +72,7 @@ static void gee_read_only_list_real_remove_at (GeeList* base, gint index);
 static gpointer gee_read_only_list_real_get (GeeList* base, gint index);
 static void gee_read_only_list_real_set (GeeList* base, gint index, gconstpointer o);
 static void gee_read_only_list_real_clear (GeeCollection* base);
+static GeeList* gee_read_only_list_real_slice (GeeList* base, gint start, gint stop);
 struct _GeeReadOnlyListIteratorPrivate {
 	GType g_type;
 	GBoxedCopyFunc g_dup_func;
@@ -104,7 +105,6 @@ GeeReadOnlyList* gee_read_only_list_construct (GType object_type, GType g_type,
 	GParameter * __params;
 	GParameter * __params_it;
 	GeeReadOnlyList * self;
-	g_return_val_if_fail (list == NULL || GEE_IS_LIST (list), NULL);
 	__params = g_new0 (GParameter, 3);
 	__params_it = __params;
 	__params_it->name = "g-type";
@@ -137,34 +137,34 @@ GeeReadOnlyList* gee_read_only_list_new (GType g_type, GBoxedCopyFunc g_dup_func
 
 static GType gee_read_only_list_real_get_element_type (GeeIterable* base) {
 	GeeReadOnlyList * self;
-	self = GEE_READ_ONLY_LIST (base);
+	self = (GeeReadOnlyList*) base;
 	return self->priv->g_type;
 }
 
 
 static GeeIterator* gee_read_only_list_real_iterator (GeeIterable* base) {
 	GeeReadOnlyList * self;
-	self = GEE_READ_ONLY_LIST (base);
+	self = (GeeReadOnlyList*) base;
 	if (self->priv->_list == NULL) {
-		return GEE_ITERATOR (gee_read_only_list_iterator_new (self->priv->g_type, ((GBoxedCopyFunc) (self->priv->g_dup_func)), self->priv->g_destroy_func));
+		return (GeeIterator*) gee_read_only_list_iterator_new (self->priv->g_type, (GBoxedCopyFunc) self->priv->g_dup_func, self->priv->g_destroy_func);
 	}
-	return gee_iterable_iterator (GEE_ITERABLE (self->priv->_list));
+	return gee_iterable_iterator ((GeeIterable*) self->priv->_list);
 }
 
 
 static gboolean gee_read_only_list_real_contains (GeeCollection* base, gconstpointer item) {
 	GeeReadOnlyList * self;
-	self = GEE_READ_ONLY_LIST (base);
+	self = (GeeReadOnlyList*) base;
 	if (self->priv->_list == NULL) {
 		return FALSE;
 	}
-	return gee_collection_contains (GEE_COLLECTION (self->priv->_list), item);
+	return gee_collection_contains ((GeeCollection*) self->priv->_list, item);
 }
 
 
 static gint gee_read_only_list_real_index_of (GeeList* base, gconstpointer item) {
 	GeeReadOnlyList * self;
-	self = GEE_READ_ONLY_LIST (base);
+	self = (GeeReadOnlyList*) base;
 	if (self->priv->_list == NULL) {
 		return -1;
 	}
@@ -174,35 +174,35 @@ static gint gee_read_only_list_real_index_of (GeeList* base, gconstpointer item)
 
 static gboolean gee_read_only_list_real_add (GeeCollection* base, gconstpointer item) {
 	GeeReadOnlyList * self;
-	self = GEE_READ_ONLY_LIST (base);
+	self = (GeeReadOnlyList*) base;
 	g_assert_not_reached ();
 }
 
 
 static gboolean gee_read_only_list_real_remove (GeeCollection* base, gconstpointer item) {
 	GeeReadOnlyList * self;
-	self = GEE_READ_ONLY_LIST (base);
+	self = (GeeReadOnlyList*) base;
 	g_assert_not_reached ();
 }
 
 
 static void gee_read_only_list_real_insert (GeeList* base, gint index, gconstpointer item) {
 	GeeReadOnlyList * self;
-	self = GEE_READ_ONLY_LIST (base);
+	self = (GeeReadOnlyList*) base;
 	g_assert_not_reached ();
 }
 
 
 static void gee_read_only_list_real_remove_at (GeeList* base, gint index) {
 	GeeReadOnlyList * self;
-	self = GEE_READ_ONLY_LIST (base);
+	self = (GeeReadOnlyList*) base;
 	g_assert_not_reached ();
 }
 
 
 static gpointer gee_read_only_list_real_get (GeeList* base, gint index) {
 	GeeReadOnlyList * self;
-	self = GEE_READ_ONLY_LIST (base);
+	self = (GeeReadOnlyList*) base;
 	if (self->priv->_list == NULL) {
 		return NULL;
 	}
@@ -212,46 +212,53 @@ static gpointer gee_read_only_list_real_get (GeeList* base, gint index) {
 
 static void gee_read_only_list_real_set (GeeList* base, gint index, gconstpointer o) {
 	GeeReadOnlyList * self;
-	self = GEE_READ_ONLY_LIST (base);
+	self = (GeeReadOnlyList*) base;
 	g_assert_not_reached ();
 }
 
 
 static void gee_read_only_list_real_clear (GeeCollection* base) {
 	GeeReadOnlyList * self;
-	self = GEE_READ_ONLY_LIST (base);
+	self = (GeeReadOnlyList*) base;
+	g_assert_not_reached ();
+}
+
+
+static GeeList* gee_read_only_list_real_slice (GeeList* base, gint start, gint stop) {
+	GeeReadOnlyList * self;
+	self = (GeeReadOnlyList*) base;
 	g_assert_not_reached ();
 }
 
 
 static gint gee_read_only_list_real_get_size (GeeCollection* base) {
 	GeeReadOnlyList* self;
-	self = GEE_READ_ONLY_LIST (base);
-	return gee_collection_get_size (GEE_COLLECTION (self->priv->_list));
+	self = (GeeReadOnlyList*) base;
+	return gee_collection_get_size ((GeeCollection*) self->priv->_list);
 }
 
 
 void gee_read_only_list_set_list (GeeReadOnlyList* self, GeeList* value) {
 	GeeList* _tmp1;
 	GeeList* _tmp0;
-	g_return_if_fail (GEE_IS_READ_ONLY_LIST (self));
+	g_return_if_fail (self != NULL);
 	_tmp1 = NULL;
 	_tmp0 = NULL;
-	self->priv->_list = (_tmp1 = (_tmp0 = value, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0))), (self->priv->_list == NULL ? NULL : (self->priv->_list = (g_object_unref (self->priv->_list), NULL))), _tmp1);
-	g_object_notify (((GObject *) (self)), "list");
+	self->priv->_list = (_tmp1 = (_tmp0 = value, (_tmp0 == NULL) ? NULL : g_object_ref (_tmp0)), (self->priv->_list == NULL) ? NULL : (self->priv->_list = (g_object_unref (self->priv->_list), NULL)), _tmp1);
+	g_object_notify ((GObject *) self, "list");
 }
 
 
 static gboolean gee_read_only_list_iterator_real_next (GeeIterator* base) {
 	GeeReadOnlyListIterator * self;
-	self = GEE_READ_ONLY_LIST_ITERATOR (base);
+	self = (GeeReadOnlyListIterator*) base;
 	return FALSE;
 }
 
 
 static gpointer gee_read_only_list_iterator_real_get (GeeIterator* base) {
 	GeeReadOnlyListIterator * self;
-	self = GEE_READ_ONLY_LIST_ITERATOR (base);
+	self = (GeeReadOnlyListIterator*) base;
 	return NULL;
 }
 
@@ -291,6 +298,7 @@ static GeeReadOnlyListIterator* gee_read_only_list_iterator_new (GType g_type, G
 
 static void gee_read_only_list_iterator_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	GeeReadOnlyListIterator * self;
+	gpointer boxed;
 	self = GEE_READ_ONLY_LIST_ITERATOR (object);
 	switch (property_id) {
 		default:
@@ -304,6 +312,9 @@ static void gee_read_only_list_iterator_set_property (GObject * object, guint pr
 	GeeReadOnlyListIterator * self;
 	self = GEE_READ_ONLY_LIST_ITERATOR (object);
 	switch (property_id) {
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 		case GEE_READ_ONLY_LIST_ITERATOR_G_TYPE:
 		self->priv->g_type = g_value_get_gtype (value);
 		break;
@@ -313,9 +324,6 @@ static void gee_read_only_list_iterator_set_property (GObject * object, guint pr
 		case GEE_READ_ONLY_LIST_ITERATOR_G_DESTROY_FUNC:
 		self->priv->g_destroy_func = g_value_get_pointer (value);
 		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
 	}
 }
 
@@ -357,10 +365,11 @@ static GType gee_read_only_list_iterator_get_type (void) {
 
 static void gee_read_only_list_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	GeeReadOnlyList * self;
+	gpointer boxed;
 	self = GEE_READ_ONLY_LIST (object);
 	switch (property_id) {
 		case GEE_READ_ONLY_LIST_SIZE:
-		g_value_set_int (value, gee_collection_get_size (GEE_COLLECTION (self)));
+		g_value_set_int (value, gee_collection_get_size ((GeeCollection*) self));
 		break;
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -376,6 +385,9 @@ static void gee_read_only_list_set_property (GObject * object, guint property_id
 		case GEE_READ_ONLY_LIST_LIST:
 		gee_read_only_list_set_list (self, g_value_get_object (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 		case GEE_READ_ONLY_LIST_G_TYPE:
 		self->priv->g_type = g_value_get_gtype (value);
 		break;
@@ -385,9 +397,6 @@ static void gee_read_only_list_set_property (GObject * object, guint property_id
 		case GEE_READ_ONLY_LIST_G_DESTROY_FUNC:
 		self->priv->g_destroy_func = g_value_get_pointer (value);
 		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
 	}
 }
 
@@ -430,6 +439,7 @@ static void gee_read_only_list_gee_list_interface_init (GeeListIface * iface) {
 	iface->remove_at = gee_read_only_list_real_remove_at;
 	iface->get = gee_read_only_list_real_get;
 	iface->set = gee_read_only_list_real_set;
+	iface->slice = gee_read_only_list_real_slice;
 }
 
 
@@ -441,7 +451,7 @@ static void gee_read_only_list_instance_init (GeeReadOnlyList * self) {
 static void gee_read_only_list_finalize (GObject* obj) {
 	GeeReadOnlyList * self;
 	self = GEE_READ_ONLY_LIST (obj);
-	(self->priv->_list == NULL ? NULL : (self->priv->_list = (g_object_unref (self->priv->_list), NULL)));
+	(self->priv->_list == NULL) ? NULL : (self->priv->_list = (g_object_unref (self->priv->_list), NULL));
 	G_OBJECT_CLASS (gee_read_only_list_parent_class)->finalize (obj);
 }
 
