@@ -1,4 +1,4 @@
-/* testarraylist.vala
+/* testhashmap.vala
  *
  * Copyright (C) 2008  Jürg Billeter
  *
@@ -25,11 +25,26 @@
 
 #include <glib.h>
 #include <glib-object.h>
+#include <stdlib.h>
+#include <string.h>
 
 G_BEGIN_DECLS
 
 
 
+void test_arraylist_get (void);
+void test_arraylist_set (void);
+void test_arraylist_insert (void);
+void test_arraylist_remove_at (void);
+void test_arraylist_index_of (void);
+void test_arraylist_add (void);
+void test_arraylist_clear (void);
+void test_arraylist_contains (void);
+void test_arraylist_remove (void);
+void test_arraylist_size (void);
+void test_arraylist_iterator (void);
+void _main (char** args, int args_length1);
+
 
 G_END_DECLS
 
